@@ -3,7 +3,7 @@
     Smb4K.
                              -------------------
     begin                : Do Apr 2 2009
-    copyright            : (C) 2009-2017 by Alexander Reinholdt
+    copyright            : (C) 2009-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -42,19 +42,38 @@ class Smb4KBasicNetworkItemPrivate
   public:
     NetworkItem type;
     QIcon icon;
+    QUrl url;
 };
 
 
 Smb4KBasicNetworkItem::Smb4KBasicNetworkItem(NetworkItem type)
 : d(new Smb4KBasicNetworkItemPrivate)
 {
+  //
+  // Set the type
+  // 
   d->type = type;
+  
+  //
+  // Initialize the protected variables
+  // 
+  pUrl = &d->url;
+  pIcon = &d->icon;
 }
 
 Smb4KBasicNetworkItem::Smb4KBasicNetworkItem(const Smb4KBasicNetworkItem &item)
 : d(new Smb4KBasicNetworkItemPrivate)
 {
+  //
+  // Copy the private variables
+  // 
   *d = *item.d;
+  
+  //
+  // Initialize the protected variables
+  // 
+  pUrl = &d->url;
+  pIcon = &d->icon;
 }
 
 
@@ -80,3 +99,75 @@ QIcon Smb4KBasicNetworkItem::icon() const
   return d->icon;
 }
 
+
+void Smb4KBasicNetworkItem::setUrl(const QUrl& url)
+{
+  //
+  // Check that the URL is valid
+  // 
+  if (!url.isValid())
+  {
+    return;
+  }
+  
+  //
+  // Do some checks depending on the type of the network item
+  // 
+  switch (d->type)
+  {
+    case Network:
+    {
+      break;
+    }
+    case Workgroup:
+    case Host:
+    {
+      // 
+      // Check that the host name is present and there is no path
+      // 
+      if (url.host().isEmpty() || !url.path().isEmpty())
+      {
+        return;
+      }
+      
+      break;
+    }
+    case Share:
+    {
+      //
+      // Check that the share name is present
+      // 
+      if (url.path().isEmpty() || (url.path().size() == 1 && url.path().endsWith('/')))
+      {
+        return;
+      }
+      
+      break;
+    }
+    default:
+    {
+      break;
+    }
+  }
+  
+  //
+  // Set the URL
+  //
+  d->url = url;
+  
+  //
+  // Force the scheme
+  // 
+  if (d->url.scheme() != "smb")
+  {
+    d->url.setScheme("smb");
+  }
+}
+
+
+QUrl Smb4KBasicNetworkItem::url() const
+{
+  return d->url;
+}
+
+
