@@ -2,7 +2,7 @@
     This class handles the bookmarks.
                              -------------------
     begin                : Fr Jan 9 2004
-    copyright            : (C) 2004-2017 by Alexander Reinholdt
+    copyright            : (C) 2004-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -34,7 +34,6 @@
 #include <QList>
 #include <QScopedPointer>
 #include <QUrl>
-#include <QWidget>
 
 // forward declarations
 class Smb4KBookmark;
@@ -80,20 +79,27 @@ class Q_DECL_EXPORT Smb4KBookmarkHandler : public QObject
      * This function adds a new bookmark.
      *
      * @param share         The share that is to be bookmarked.
-     * 
-     * @param parent        The parent widget
      */
-    void addBookmark(const SharePtr &share, QWidget *parent = 0);
+    void addBookmark(const SharePtr &share);
 
     /**
      * This function adds several bookmarks at once. It takes a list of 
      * shares and converts them internally to bookmark items.
      *
      * @param list          The list of shares that are to be bookmarked
-     *
-     * @param parent        The parent widget
      */
-    void addBookmarks(const QList<SharePtr> &list, QWidget *parent = 0);
+    void addBookmarks(const QList<SharePtr> &list);
+    
+    /**
+     * This function adds several bookmarks at once. It takes a list of
+     * Smb4KBookmark items.
+     * 
+     * @param list          The list of bookmarks that are to be bookmarked
+     * 
+     * @param replace       If TRUE the old list of bookmarks is replaced by
+     *                      @p list.
+     */
+    void addBookmarks(const QList<BookmarkPtr> &list, bool replace = false);
     
     /**
      * Remove a bookmark.
@@ -127,15 +133,15 @@ class Q_DECL_EXPORT Smb4KBookmarkHandler : public QObject
     QList<BookmarkPtr> bookmarksList(const QString &group) const;
     
     /**
-     * This function searches for a bookmark using its UNC and returns a pointer
+     * This function searches for a bookmark using its URL and returns a pointer
      * to it if it is present or NULL.
      *
-     * @param UNC           The UNC of the bookmark that is searched.
+     * @param url           The URL of the bookmark that is searched.
      *
      * @returns the bookmark object that was searched for or NULL if it was not
      * found.
      */
-    BookmarkPtr findBookmarkByUNC(const QString &unc);
+    BookmarkPtr findBookmarkByUrl(const QUrl &url);
 
     /**
      * This function searches for a bookmark using its label and returns a pointer
@@ -154,18 +160,23 @@ class Q_DECL_EXPORT Smb4KBookmarkHandler : public QObject
      * @returns the list of groups
      */
     QStringList groupsList() const;  
-
-    /**
-     * Opens the bookmark editor
-     * 
-     * @param parent          The parent widget
-     */
-    void editBookmarks(QWidget *parent = 0);
     
     /**
      * Reset the bookmarks by reloading them from the file.              
      */
     void resetBookmarks();
+    
+    /**
+     * This function checks if the @p share is already bookmarked or not.
+     * @param share         The share item
+     * @returns TRUE if the share is bookmarked and FALSE otherwise.
+     */
+    bool isBookmarked(const SharePtr &share);
+    
+    /**
+     * This function opens the bookmark editor.
+     */
+    void editBookmarks();
 
   Q_SIGNALS:
     /**
@@ -177,7 +188,7 @@ class Q_DECL_EXPORT Smb4KBookmarkHandler : public QObject
     /**
      * This function reads the list of bookmarks from the bookmarks file.
      */
-    void readBookmarks();
+    void readBookmarkList();
 
     /**
      * This function updates the data of the bookmarks, i.e. is searches for
@@ -191,17 +202,6 @@ class Q_DECL_EXPORT Smb4KBookmarkHandler : public QObject
      */
     void writeBookmarkList();
 
-    /**
-     * This function adds several bookmarks at once. It takes a list of
-     * Smb4KBookmark items.
-     * 
-     * @param list          The list of bookmarks that are to be bookmarked
-     * 
-     * @param replace       If TRUE the old list of bookmarks is replaced by
-     *                      @p list.
-     */
-    void addBookmarks(const QList<BookmarkPtr> &list, bool replace = false);
-    
     /**
      * Migrates one profile to another.
      * 
