@@ -2,7 +2,7 @@
     Private classes for the bookmark handler
                              -------------------
     begin                : Sun Mar 20 2011
-    copyright            : (C) 2011-2017 by Alexander Reinholdt
+    copyright            : (C) 2011-2018 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -161,7 +161,7 @@ class Q_DECL_EXPORT Smb4KBookmarkDialog : public QDialog
 };
 
 
-class Q_DECL_EXPORT Smb4KBookmarkEditor : public QDialog
+class Smb4KBookmarkEditor : public QDialog
 {
   Q_OBJECT
 
@@ -179,21 +179,22 @@ class Q_DECL_EXPORT Smb4KBookmarkEditor : public QDialog
      * The destructor.
      */
     ~Smb4KBookmarkEditor();
-
+    
     /**
-     * Returns the list of bookmarks after the editing. Please note
-     * that the editor operates on an interal copy of the bookmarks
-     * passed to the constructor to prevent accidental modification.
-     *
-     * @returns the list of bookmarks
+     * Load the bookmarks into the view
      */
-    QList<BookmarkPtr> editedBookmarks() const;
+    void loadBookmarks();
+    
+    /**
+     * Return the list of edited bookmarks
+     */
+    QList<BookmarkPtr> editedBookmarks();
 
   protected:
     /**
      * Reimplemented from QObject
      */
-    bool eventFilter(QObject *obj, QEvent *e);
+    bool eventFilter(QObject *obj, QEvent *e) override;
 
   protected Q_SLOTS:
     /**
@@ -246,11 +247,19 @@ class Q_DECL_EXPORT Smb4KBookmarkEditor : public QDialog
      */
     void slotDialogAccepted();
     
+    /**
+     * Called when the Cancel button was clicked
+     */
+    void slotDialogRejected();
+    
     /**
      * Called when the icon size changed
      */
     void slotIconSizeChanged(int group);
     
+    /**
+     * Do adjustments in the list view
+     */
     void slotAdjust();
 
   private:
@@ -259,11 +268,6 @@ class Q_DECL_EXPORT Smb4KBookmarkEditor : public QDialog
      */
     void setupView();
 
-    /**
-     * Load bookmarks
-     */
-    void loadBookmarks();
-
     /**
      * Finds the bookmark in the list
      */
@@ -279,7 +283,6 @@ class Q_DECL_EXPORT Smb4KBookmarkEditor : public QDialog
      */
     QPushButton *m_cancel_button;
 
-    
     /**
      * List of the bookmarks that are being processed
      */
@@ -345,8 +348,8 @@ class Q_DECL_EXPORT Smb4KBookmarkEditor : public QDialog
 class Smb4KBookmarkHandlerPrivate
 {
   public:
-    QPointer<Smb4KBookmarkEditor> editor;
     QList<BookmarkPtr> bookmarks;
+    QPointer<Smb4KBookmarkEditor> editor;
 };
 
 
