@@ -185,11 +185,10 @@ class Q_DECL_EXPORT Smb4KCustomOptions
      * @param RemountAlways     Remount the share every time the application is
      *                          started.
      * @param RemountNever      Never remount the share.
-     * @param UndefinedRemount  No remount option is defined.
+     * @param UndefinedRemount  No remount behavior is undefined.
      */
     enum Remount { RemountOnce,
                    RemountAlways,
-                   RemountNever,
                    UndefinedRemount };
     
     /**
