@@ -2,7 +2,7 @@
     This is the global namespace for Smb4K.
                              -------------------
     begin                : Sa Apr 2 2005
-    copyright            : (C) 2005-2017 by Alexander Reinholdt
+    copyright            : (C) 2005-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -26,10 +26,6 @@
 #ifndef SMB4KGLOBAL_H
 #define SMB4KGLOBAL_H
 
-#ifndef SMB4K_DEPRECATED
-#define SMB4K_DEPRECATED __attribute__ ((__deprecated__))
-#endif
-
 // Qt includes
 #include <QMap>
 #include <QString>
@@ -43,6 +39,7 @@ class Smb4KBasicNetworkItem;
 class Smb4KWorkgroup;
 class Smb4KHost;
 class Smb4KShare;
+class Smb4KFile;
 class Smb4KBookmark;
 class Smb4KCustomOptions;
 
@@ -51,9 +48,16 @@ typedef QSharedPointer<Smb4KBasicNetworkItem> NetworkItemPtr;
 typedef QSharedPointer<Smb4KWorkgroup> WorkgroupPtr;
 typedef QSharedPointer<Smb4KHost> HostPtr;
 typedef QSharedPointer<Smb4KShare> SharePtr;
+typedef QSharedPointer<Smb4KFile> FilePtr;
 typedef QSharedPointer<Smb4KBookmark> BookmarkPtr;
 typedef QSharedPointer<Smb4KCustomOptions> OptionsPtr;
 
+// Other definitions
+#ifndef SMB4K_DEPRECATED
+#define SMB4K_DEPRECATED __attribute__ ((__deprecated__))
+#endif
+
+
 /**
  * This is the global namespace. It provides access to the global lists
  * of workgroups, hosts and shares, to the global settings of the Samba
@@ -70,52 +74,59 @@ namespace Smb4KGlobal
    * @enum LookupDomains          Look up domains
    * @enum LookupDomainMembers    Look up those servers that belong to a domain/workgroup
    * @enum LookupShares           Look up shares on a server
+   * @enum LookupFiles            Look up files and directories within a share
    * @enum WakeUp                 Send magic Wake-On-LAN packages
+   * @enum PrintFile              Print a file
+   * @enum NetworkSearch          Network search
    * @enum MountShare             Mount a share
    * @enum UnmountShare           Unmount a share
+   * @enum NoProcess              No process
    */
   enum Process { 
     LookupDomains,
     LookupDomainMembers,
     LookupShares,
+    LookupFiles,
     WakeUp,
+    PrintFile,
+    NetworkSearch,
     MountShare,
-    UnmountShare };
+    UnmountShare,
+    NoProcess };
                  
   /**
    * The enumeration to determine the type of a network item.
    * 
-   * @enum Network                the network
-   * @enum Workgroup              a workgroup
-   * @enum Host                   a host
-   * @enum Share                  a share
-   * @enum Unknown                an unknown network item 
+   * @enum Network                The network
+   * @enum Workgroup              A workgroup
+   * @enum Host                   A host
+   * @enum Share                  A share
+   * @enum Directory              A directory in a shared folder
+   * @enum File                   A file in a shared folder
+   * @enum UnknownNetworkItem     An unknown network item 
    */
   enum NetworkItem { 
     Network,
     Workgroup,
     Host,
     Share,
+    Directory,
+    File,
     UnknownNetworkItem };
-     
+    
   /**
-   * This class extends the QEvent class with Smb4K specific events
+   * The enumeration that determines the share type
+   *    
+   * @enum FileShare              a file share
+   * @enum PrinterShare           a printer share
+   * @enum IpcShare               an IPC share
    */
-  class Q_DECL_EXPORT Smb4KEvent : public QEvent
-  {
-    public:
-      static const QEvent::Type LoadSettings;
-      static const QEvent::Type SetFocus;
-      static const QEvent::Type ScanNetwork;
-      static const QEvent::Type AddBookmark;
-      static const QEvent::Type MountOrUnmountShare;
-      static const QEvent::Type EnableBookmarkAction;
-      static const QEvent::Type DisableBookmarkAction;
-      
-      explicit Smb4KEvent(QEvent::Type type);
-      ~Smb4KEvent();
+  enum ShareType {
+    FileShare,
+    PrinterShare,
+    IpcShare,
   };
-
+    
   /**
    * Use this function to initialize the core classes. Besides starting several
    * core classes such as the scanner (for an initial browse list) and the mounter
@@ -147,14 +158,6 @@ namespace Smb4KGlobal
    */
   Q_DECL_EXPORT bool coreIsRunning();
 
-  /**
-   * Set the necessary default values.
-   *
-   * You only need to run this function if you do not use the initCore() function.
-   * Check if the core has been initialized by the coreIsInitialized() function.
-   */
-  Q_DECL_EXPORT void setDefaultSettings();
-
   /**
    * Check if the core has been initialized through the initCore() function.
    *
@@ -306,14 +309,17 @@ namespace Smb4KGlobal
   Q_DECL_EXPORT const QList<SharePtr> &sharesList();
 
   /**
-   * This function returns the share with UNC @p unc located in the workgroup or
+   * This function returns the share with URL @p url located in the workgroup or
    * domain @p workgroup. If there is no such share, 0 is returned. The workgroup
    * entry may be empty.
-   * @param unc           The UNC of the share
-   * @param wokgroup      The workgroup
-   * @returns the share that matches @p unc and optionally @p workgroup or 0.
+   * 
+   * @param url           The URL of the share
+   * 
+   * @param workgroup     The workgroup
+   * 
+   * @returns the share that matches @p url and optionally @p workgroup or 0.
    */
-  Q_DECL_EXPORT SharePtr findShare(const QString &unc, const QString &workgroup = QString());
+  Q_DECL_EXPORT SharePtr findShare(const QUrl &url, const QString &workgroup = QString());
 
   /**
    * This function takes a share @p share, checks whether it is already
@@ -386,19 +392,17 @@ namespace Smb4KGlobal
   Q_DECL_EXPORT SharePtr findShareByPath(const QString &path);
 
   /**
-   * Find all mounts of a particular share with UNC @p unc on the system.
+   * Find all mounts of a particular share with URL @p url on the system.
    *
-   * This function will compare the incoming string with the UNC of each
-   * mounted share to find all shares with the same UNC. For the comparison
-   * the scheme/protocol, the user info, and the port will be stripped. You
-   * can pass the UNC in any valid format. The function will internally
-   * convert the string into a QUrl and work with that.
-   *
-   * @param unc         The UNC of the share
-   *
-   * @returns the complete list of mounts with the UNC @p unc.
+   * This function will compare the incoming URL with the URL of each
+   * mounted share to find all shares with the same URL. For the comparison
+   * the user info and the port will be stripped.
+   * 
+   * @param url         The URL of the share
+   * 
+   * @returns the complete list of mounts with the URL @p url.
    */
-  Q_DECL_EXPORT QList<SharePtr> findShareByUNC(const QString &unc);
+  Q_DECL_EXPORT QList<SharePtr> findShareByUrl(const QUrl &url);
 
   /**
    * This function returns the list of inaccessible shares.
@@ -471,20 +475,11 @@ namespace Smb4KGlobal
   Q_DECL_EXPORT void openShare(SharePtr share, OpenWith openWith = FileManager);
   
   /**
-   * Get the entries of the [global] section of the smb.conf file. By setting @p read 
-   * to TRUE you can force the smb.conf file to be reread.
+   * Get the entries of the [global] section of the smb.conf file.
    * 
    * @returns the entries of the [global] section of the smb.conf file
    */
-  Q_DECL_EXPORT const QMap<QString,QString> &globalSambaOptions(bool read = false);
-  
-  /**
-   * Get the WINS server's name or IP address. Returns an empty string if there is no
-   * WINS server is defined.
-   * 
-   * @returns the WINS server
-   */
-  Q_DECL_EXPORT const QString winsServer();
+  Q_DECL_EXPORT const QMap<QString,QString> &globalSambaOptions();
   
   /**
    * This function returns TRUE if the core classes should set a busy cursor when 
@@ -497,7 +492,7 @@ namespace Smb4KGlobal
 #if defined(Q_OS_LINUX)
   /**
    * This list contains all whitelisted arguments for the mount.cifs binary and
-   * is only present under the Linux operatin system.
+   * is only present under the Linux operating system.
    */
   Q_DECL_EXPORT QStringList whitelistedMountArguments();
 #endif
