@@ -2,7 +2,7 @@
     This file contains private helper classes for the Smb4KMounter class.
                              -------------------
     begin                : Do Jul 19 2007
-    copyright            : (C) 2007-2017 by Alexander Reinholdt
+    copyright            : (C) 2007-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -33,14 +33,8 @@
 #include "smb4knotification.h"
 #include "smb4khomesshareshandler.h"
 #include "smb4kglobal.h"
-#include "smb4kcustomoptionsmanager.h"
 #include "smb4kcustomoptions.h"
-
-#if defined(Q_OS_LINUX)
-#include "smb4kmountsettings_linux.h"
-#elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
-#include "smb4kmountsettings_freebsd.h"
-#endif
+#include "smb4kcustomoptionsmanager.h"
 
 // Qt includes
 #include <QUrl>
@@ -49,6 +43,7 @@
 #include <QGridLayout>
 #include <QLabel>
 #include <QDialogButtonBox>
+#include <QWindow>
 
 // KDE includes
 #define TRANSLATION_DOMAIN "smb4k-core"
@@ -62,15 +57,39 @@ using namespace Smb4KGlobal;
 Smb4KMountDialog::Smb4KMountDialog(const SharePtr &share, QWidget *parent)
 : QDialog(parent), m_share(share), m_valid(true)
 {
+  //
+  // Set the title
+  // 
   setWindowTitle(i18n("Mount Share"));
   
+  //
+  // Set up the view
+  // 
   setupView();
-
-  setMinimumWidth(sizeHint().width() > 350 ? sizeHint().width() : 350);
+  
+  //
+  // Set the dialog size
+  // 
+  create();
 
   KConfigGroup group(Smb4KSettings::self()->config(), "MountDialog");
-  KWindowConfig::saveWindowSize(windowHandle(), group);
+  QSize dialogSize;
+  
+  if (group.exists())
+  {
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    dialogSize = windowHandle()->size();
+  }
+  else
+  {
+    dialogSize = sizeHint();
+  }
+  
+  resize(dialogSize); // workaround for QTBUG-40584
 
+  //
+  // Fill the completion objects
+  // 
   m_share_input->completionObject()->setItems(group.readEntry("ShareNameCompletion", QStringList()));
   m_ip_input->completionObject()->setItems(group.readEntry("IPAddressCompletion", QStringList()));
   m_workgroup_input->completionObject()->setItems(group.readEntry("WorkgroupCompletion", QStringList()));
@@ -97,8 +116,7 @@ void Smb4KMountDialog::setupView()
   pixmap->setPixmap(mount_pix);
   pixmap->setAlignment(Qt::AlignBottom);
 
-  QLabel *label = new QLabel(i18n("Enter the location (UNC address) and optionally the IP address and "
-                                    "workgroup to mount a share."), description);
+  QLabel *label = new QLabel(i18n("Enter the location and optionally the IP address and workgroup to mount a share."), description);
   label->setWordWrap(true);
   label->setAlignment(Qt::AlignBottom);
 
@@ -110,14 +128,13 @@ void Smb4KMountDialog::setupView()
   QGridLayout *edit_layout = new QGridLayout(edit_widget);
   layout->setSpacing(5);
 
-  QLabel *shareLabel = new QLabel(i18n("UNC Address:"), edit_widget);
+  QLabel *shareLabel = new QLabel(i18n("Location:"), edit_widget);
   m_share_input = new KLineEdit(edit_widget);
-  m_share_input->setWhatsThis(i18n("The Uniform Naming Convention (UNC) address "
-    "describes the location of the share. It has the following syntax: "
-    "//[USER@]HOST/SHARE. The username is optional."));
-//   m_share_input->setToolTip(i18n("The UNC address of the share"));
+  m_share_input->setWhatsThis(i18n("The location of the share is provided by the Uniform Resource Locator (URL). It generally has the following syntax: "
+    "[smb:]//[USER:PASSWORD@]HOST:PORT/SHARE. The username, password and port are optional. You should omit to enter the password here, because it is shown in cleartext."));
+//   m_share_input->setToolTip(i18n("The URL of the share"));
   m_share_input->setCompletionMode(KCompletion::CompletionPopupAuto);
-  m_share_input->setClearButtonShown(true);
+  m_share_input->setClearButtonEnabled(true);
   m_share_input->setMinimumWidth(200);
   m_share_input->setFocus();
 
@@ -129,7 +146,7 @@ void Smb4KMountDialog::setupView()
     "(e.g. 2001:0db8:85a3:08d3:1319:8a2e:0370:7334)."));
 //   m_ip_input->setToolTip(i18n("The IP address of the host where the share is located"));
   m_ip_input->setCompletionMode(KCompletion::CompletionPopupAuto);
-  m_ip_input->setClearButtonShown(true);
+  m_ip_input->setClearButtonEnabled(true);
   m_ip_input->setMinimumWidth(200);
 
   QLabel *workgroupLabel = new QLabel(i18n("Workgroup:"), edit_widget);
@@ -138,7 +155,7 @@ void Smb4KMountDialog::setupView()
     "peer-to-peer computer network the host is located in."));
 //   m_workgroup_input->setToolTip(i18n("The workgroup where the host is located"));
   m_workgroup_input->setCompletionMode(KCompletion::CompletionPopupAuto);
-  m_workgroup_input->setClearButtonShown(true);
+  m_workgroup_input->setClearButtonEnabled(true);
   m_workgroup_input->setMinimumWidth(200);
 
   edit_layout->addWidget(shareLabel, 0, 0, 0);
@@ -167,24 +184,15 @@ void Smb4KMountDialog::setupView()
 
   slotChangeInputValue(m_share_input->text());
 
+  // 
   // Connections
-  connect(m_share_input, SIGNAL(textChanged(QString)) ,
-          this, SLOT(slotChangeInputValue(QString)));
-
-  connect(m_share_input, SIGNAL(editingFinished()),
-          this, SLOT(slotShareNameEntered()));
-
-  connect(m_ip_input, SIGNAL(editingFinished()),
-          this, SLOT(slotIPEntered()));
-
-  connect(m_workgroup_input, SIGNAL(editingFinished()),
-          this, SLOT(slotWorkgroupEntered()));
-  
-  connect(m_ok_button, SIGNAL(clicked()), 
-          this, SLOT(slotOkClicked()));
-  
-  connect(m_cancel_button, SIGNAL(clicked()), 
-          this, SLOT(slotCancelClicked()));
+  // 
+  connect(m_share_input, SIGNAL(textChanged(QString)), this, SLOT(slotChangeInputValue(QString)));
+  connect(m_share_input, SIGNAL(editingFinished()), this, SLOT(slotShareNameEntered()));
+  connect(m_ip_input, SIGNAL(editingFinished()), this, SLOT(slotIPEntered()));
+  connect(m_workgroup_input, SIGNAL(editingFinished()), this, SLOT(slotWorkgroupEntered()));
+  connect(m_ok_button, SIGNAL(clicked()), this, SLOT(slotOkClicked()));
+  connect(m_cancel_button, SIGNAL(clicked()), this, SLOT(slotCancelClicked()));
 }
 
 
@@ -202,27 +210,33 @@ void Smb4KMountDialog::slotOkClicked()
 {
   if (!m_share_input->text().trimmed().isEmpty())
   {
-    QUrl url;
-
-    // Take care of Windows-like UNC addresses:
-    if (m_share_input->text().trimmed().startsWith(QLatin1String("\\")))
+    //
+    // Get the URL
+    // 
+    QString userInput = m_share_input->text().trimmed();
+    
+    //
+    // Take care of a Windows-like UNC addresses
+    // 
+    if (userInput.startsWith(QLatin1String("\\")))
     {
-      QString unc = m_share_input->text();
-      unc.replace("\\", "/");
-      url.setUrl(unc, QUrl::TolerantMode);
+      userInput.replace("\\", "/");
     }
-    else
+    
+    //
+    // Set the URL and adjust the scheme
+    // 
+    QUrl smbUrl = QUrl::fromUserInput(userInput);
+    smbUrl.setScheme("smb");
+    
+    //
+    // Set the URL of the share
+    // 
+    if (smbUrl.isValid() && !smbUrl.host().isEmpty() && !smbUrl.path().isEmpty() && !smbUrl.path().endsWith(QLatin1String("/")))
     {
-      url.setUrl(m_share_input->text().trimmed(), QUrl::TolerantMode);
-    }
-
-    url.setScheme("smb");
-
-    if (url.isValid() && !url.host().isEmpty() && !url.path().isEmpty() && !url.path().endsWith('/'))
-    {
-      m_share->setURL(url);
+      m_share->setUrl(smbUrl);
       m_share->setWorkgroupName(m_workgroup_input->text().trimmed());
-      m_share->setHostIP(m_ip_input->text().trimmed());
+      m_share->setHostIpAddress(m_ip_input->text().trimmed());
     }
     else
     {
@@ -230,11 +244,7 @@ void Smb4KMountDialog::slotOkClicked()
       m_valid = false;
     }
   }
-  else
-  {
-    // Do nothing
-  }
-
+  
   KConfigGroup group(Smb4KSettings::self()->config(), "MountDialog");
   KWindowConfig::saveWindowSize(windowHandle(), group);
   group.writeEntry("ShareNameCompletion", m_share_input->completionObject()->items());
@@ -247,7 +257,7 @@ void Smb4KMountDialog::slotOkClicked()
 
 void Smb4KMountDialog::slotCancelClicked()
 {
-  Smb4KMounter::self()->abortAll();
+  Smb4KMounter::self()->abort();
   reject();
 }
 
@@ -262,10 +272,6 @@ void Smb4KMountDialog::slotShareNameEntered()
   {
     completion->addItem(m_share_input->userText());
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -277,10 +283,6 @@ void Smb4KMountDialog::slotIPEntered()
   {
     completion->addItem(m_ip_input->userText());
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -292,9 +294,5 @@ void Smb4KMountDialog::slotWorkgroupEntered()
   {
     completion->addItem(m_workgroup_input->userText());
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
