@@ -32,7 +32,8 @@
 #include "smb4kglobal.h"
 
 // Qt includes
-#include <QHostAddress>
+#include <QAbstractSocket>
+#include <QUrl>
 
 // KDE includes
 #include <KIconThemes/KIconLoader>
@@ -42,7 +43,6 @@ using namespace Smb4KGlobal;
 class Smb4KWorkgroupPrivate
 {
   public:
-    QUrl url;
     QUrl masterURL;
     QHostAddress masterIP;
 };
@@ -51,24 +51,32 @@ class Smb4KWorkgroupPrivate
 Smb4KWorkgroup::Smb4KWorkgroup(const QString &name)
 : Smb4KBasicNetworkItem(Workgroup), d(new Smb4KWorkgroupPrivate)
 {
-  d->url.setHost(name);
-  d->url.setScheme("smb");
-  setIcon(KDE::icon("network-workgroup"));
+  // 
+  // Set the URL of the workgroup
+  // 
+  pUrl->setScheme("smb");
+  pUrl->setHost(name);
+  
+  //
+  // Set the icon
+  // 
+  *pIcon = KDE::icon("network-workgroup");
 }
 
 
 Smb4KWorkgroup::Smb4KWorkgroup(const Smb4KWorkgroup &w)
 : Smb4KBasicNetworkItem(Workgroup), d(new Smb4KWorkgroupPrivate)
 {
+  // Copy the private variables
+  // 
   *d = *w.d;
   
-  if (icon().isNull())
+  //
+  // Set the icon if necessary
+  // 
+  if (pIcon->isNull())
   {
-    setIcon(KDE::icon("network-workgroup"));
-  }
-  else
-  {
-    // Do nothing
+    *pIcon = KDE::icon("network-workgroup");
   }
 }
 
@@ -76,7 +84,15 @@ Smb4KWorkgroup::Smb4KWorkgroup(const Smb4KWorkgroup &w)
 Smb4KWorkgroup::Smb4KWorkgroup()
 : Smb4KBasicNetworkItem(Workgroup), d(new Smb4KWorkgroupPrivate)
 {
-  setIcon(KDE::icon("network-workgroup"));  
+  //
+  // Set the URL
+  //
+  pUrl->setScheme("smb");
+  
+  //
+  // Set the icon
+  // 
+  *pIcon = KDE::icon("network-workgroup");  
 }
 
 
@@ -87,14 +103,14 @@ Smb4KWorkgroup::~Smb4KWorkgroup()
 
 void Smb4KWorkgroup::setWorkgroupName(const QString &name)
 {
-  d->url.setHost(name);
-  d->url.setScheme("smb");
+  pUrl->setHost(name);
+  pUrl->setScheme("smb");
 }
 
 
 QString Smb4KWorkgroup::workgroupName() const
 {
-  return d->url.host().toUpper();
+  return pUrl->host().toUpper();
 }
 
 
@@ -111,103 +127,44 @@ QString Smb4KWorkgroup::masterBrowserName() const
 }
 
 
-void Smb4KWorkgroup::setMasterBrowserIP(const QString &ip)
+void Smb4KWorkgroup::setMasterBrowserIpAddress(const QString &ip)
 {
   d->masterIP.setAddress(ip);
 }
 
 
-QString Smb4KWorkgroup::masterBrowserIP() const
+void Smb4KWorkgroup::setMasterBrowserIpAddress(const QHostAddress& address)
+{
+  if (!address.isNull() && address.protocol() != QAbstractSocket::UnknownNetworkLayerProtocol)
+  {
+    d->masterIP = address;
+  }
+}
+
+
+QString Smb4KWorkgroup::masterBrowserIpAddress() const
 {
   return d->masterIP.toString();
 }
 
 
-bool Smb4KWorkgroup::isEmpty() const
-{
-  // Ignore all booleans.
-
-  if (!d->url.host().isEmpty())
-  {
-    return false;
-  }
-
-  if (!d->masterURL.host().isEmpty())
-  {
-    return false;
-  }
-
-  if (!d->masterIP.isNull())
-  {
-    return false;
-  }
-  
-  // Do not include the icon here.
-
-  return true;
-}
-
-
-bool Smb4KWorkgroup::equals(Smb4KWorkgroup *workgroup) const
-{
-  Q_ASSERT(workgroup);
-
-  if (QString::compare(workgroupName(), workgroup->workgroupName()) != 0)
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  if (QString::compare(masterBrowserName(), workgroup->masterBrowserName()) != 0)
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  if (QString::compare(masterBrowserIP(), workgroup->masterBrowserIP()) != 0)
-  {
-    return false;
-  }
-  else
-  {
-    // Do nothing
-  }
-
-  // Do not include the icon here.
-
-  return true;
-}
-
-
-bool Smb4KWorkgroup::hasMasterBrowserIP() const
+bool Smb4KWorkgroup::hasMasterBrowserIpAddress() const
 {
   return !d->masterIP.isNull();
 }
 
 
-QUrl Smb4KWorkgroup::url() const
-{
-  return d->url;
-}
-
-
 void Smb4KWorkgroup::update(Smb4KWorkgroup* workgroup)
 {
   if (QString::compare(workgroupName(), workgroup->workgroupName()) == 0)
   {
     setMasterBrowserName(workgroup->masterBrowserName());
-    setMasterBrowserIP(workgroup->masterBrowserIP());
-  }
-  else
-  {
-    // Do nothing
+    setMasterBrowserIpAddress(workgroup->masterBrowserIpAddress());
   }
+
+  
+  
+  
 }
 
 
