@@ -2,7 +2,7 @@
     The configuration dialog of Smb4K
                              -------------------
     begin                : Sa Apr 14 2007
-    copyright            : (C) 2004-2017 by Alexander Reinholdt
+    copyright            : (C) 2004-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -63,19 +63,19 @@ class Q_DECL_EXPORT Smb4KConfigDialog : public KConfigDialog
      * Reimplemented from KConfigDialog. Used to do things that 
      * KConfigDialog::updateSettings() does not do.
      */
-    void updateSettings();
+    void updateSettings() override;
     
     /**
      * Reimplemented from KConfigDialog. Used to do things before
      * the dialog is shown.
      */
-    void updateWidgets();
+    void updateWidgets() override;
     
     /**
      * Reimplemented from QDialog. Used to reset things after the dialog was
      * closed via the 'Cancel' button.
      */
-    void reject();
+    void reject() override;
     
     /**
      * This slot is connected to the "Load" button of the "Wallet Entries" tab
@@ -103,11 +103,6 @@ class Q_DECL_EXPORT Smb4KConfigDialog : public KConfigDialog
      */
     void slotEnableApplyButton();
     
-    /**
-     * Reload custom options
-     */
-    void slotReloadCustomOptions();
-    
     /**
      * This slot is used to check the settings of the different pages.
      * 
@@ -127,21 +122,11 @@ class Q_DECL_EXPORT Smb4KConfigDialog : public KConfigDialog
      */
     KPageWidgetItem *m_network;
     
-    /**
-     * "Shares" page
-     */
-    KPageWidgetItem *m_shares;
-    
     /**
      * "Authentication" page
      */
     KPageWidgetItem *m_authentication;
     
-    /**
-     * "Samba" page
-     */
-    KPageWidgetItem *m_samba;
-    
     /**
      * "Mounting" page
      */
@@ -190,13 +175,6 @@ class Q_DECL_EXPORT Smb4KConfigDialog : public KConfigDialog
      */
     bool checkNetworkPage();
     
-    /**
-     * Checks the settings in the Shares page.
-     * 
-     * @returns TRUE if everything is OK and FALSE otherwise.
-     */
-    bool checkSharesPage();
-    
     /**
      * Checks the settings in the Mounting page.
      * 
@@ -212,7 +190,7 @@ class Q_DECL_EXPORT Smb4KConfigDialog : public KConfigDialog
     bool checkSynchronizationPage();
 
     /**
-     * Checks that mandatorily needed input is provided for settings that
+     * Checks that mandatory needed input is provided for settings that
      * need it. This function will report all missing input to the user
      * via a message box.
      *
