@@ -2,7 +2,7 @@
     The configuration page for the mount options
                              -------------------
     begin                : So Mär 22 2015
-    copyright            : (C) 2015-2017 by Alexander Reinholdt
+    copyright            : (C) 2015-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -66,12 +66,26 @@ class Smb4KConfigPageMounting : public QTabWidget
      */
     void slotNewGroupTriggered(QAction *action);
     
+    /**
+     * Enable / disable the options that are only necessary when the servers
+     * do not support the CIFS Unix extensions.
+     * 
+     * @param checked             TRUE if the button is checked
+     */
+    void slotCIFSUnixExtensionsSupport(bool checked);
+    
     /**
      * This slot is activated when the additional CIFS options are to be
-     * edited.
+     * edited (Linux only).
      */
     void slotAdditionalCIFSOptions();
     
+    /**
+     * This slot is activated when the setting of the character set usage is changed
+     * (BSD only).
+     */
+    void slotCharacterSets(bool on);
+    
   private:
     /**
      * Set up the widget
