@@ -3,7 +3,7 @@
     user interface
                              -------------------
     begin                : Mi Aug 30 2006
-    copyright            : (C) 2006-2017 by Alexander Reinholdt
+    copyright            : (C) 2006-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -37,7 +37,7 @@
  * @author Alexander Reinholdt  <alexander.reinholdt@kdemail.net>
  */
 
-class Smb4KConfigPageUserInterface : public QTabWidget
+class Smb4KConfigPageUserInterface : public QWidget
 {
   Q_OBJECT
 
