@@ -2,7 +2,7 @@
     smb4knetworkbrowser  -  The network browser widget of Smb4K.
                              -------------------
     begin                : Mo Jan 8 2007
-    copyright            : (C) 2007-2017 by Alexander Reinholdt
+    copyright            : (C) 2007-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -73,18 +73,13 @@ Smb4KNetworkBrowser::Smb4KNetworkBrowser(QWidget *parent)
 
   header()->setSectionResizeMode(QHeaderView::ResizeToContents);
 
-  // Add some connections:
-  connect(this, SIGNAL(itemActivated(QTreeWidgetItem*,int)),
-          this, SLOT(slotItemActivated(QTreeWidgetItem*,int)));
-
-  connect(this, SIGNAL(itemEntered(QTreeWidgetItem*,int)),
-          this, SLOT(slotItemEntered(QTreeWidgetItem*,int)));
-
-  connect(this, SIGNAL(viewportEntered()),
-          this, SLOT(slotViewportEntered()));
-
-  connect(this, SIGNAL(itemSelectionChanged()),
-          this, SLOT(slotItemSelectionChanged()));
+  // 
+  // Connections
+  // 
+  connect(this, SIGNAL(itemActivated(QTreeWidgetItem*,int)), this, SLOT(slotItemActivated(QTreeWidgetItem*,int)));
+  connect(this, SIGNAL(itemEntered(QTreeWidgetItem*,int)), this, SLOT(slotItemEntered(QTreeWidgetItem*,int)));
+  connect(this, SIGNAL(viewportEntered()), this, SLOT(slotViewportEntered()));
+  connect(this, SIGNAL(itemSelectionChanged()), this, SLOT(slotItemSelectionChanged()));
 }
 
 
@@ -138,10 +133,6 @@ bool Smb4KNetworkBrowser::event(QEvent *e)
               m_tooltip_item->tooltip()->hide();
               m_tooltip_item = 0;
             }
-            else
-            {
-              // Do nothing
-            }
           }
           else
           {
@@ -158,10 +149,6 @@ bool Smb4KNetworkBrowser::event(QEvent *e)
             m_tooltip_item->tooltip()->hide();
             m_tooltip_item = 0;
           }
-          else
-          {
-            // Do nothing
-          }         
         }
       }
       else
@@ -172,10 +159,6 @@ bool Smb4KNetworkBrowser::event(QEvent *e)
           m_tooltip_item->tooltip()->hide();
           m_tooltip_item = 0;
         }
-        else
-        {
-          // Do nothing
-        }
       }
       
       break;
@@ -206,10 +189,6 @@ void Smb4KNetworkBrowser::mouseMoveEvent(QMouseEvent *e)
       m_tooltip_item->tooltip()->hide();
       m_tooltip_item = 0;
     }
-    else
-    {
-      // Do nothing
-    }
   }
   else
   {
@@ -220,10 +199,6 @@ void Smb4KNetworkBrowser::mouseMoveEvent(QMouseEvent *e)
       m_tooltip_item->tooltip()->hide();
       m_tooltip_item = 0;
     }
-    else
-    {
-      // Do nothing
-    }
   }
 
   QTreeWidget::mouseMoveEvent(e);
@@ -238,10 +213,6 @@ void Smb4KNetworkBrowser::leaveEvent(QEvent *e)
     m_tooltip_item->tooltip()->hide();
     m_tooltip_item = 0;
   }
-  else
-  {
-    // Do nothing
-  }
   
   m_mouse_inside = false;
 
@@ -266,10 +237,6 @@ void Smb4KNetworkBrowser::mousePressEvent(QMouseEvent *e)
     m_tooltip_item->tooltip()->hide();
     m_tooltip_item = 0;
   }
-  else
-  {
-    // Do nothing
-  }
 
   // Get the item that is under the mouse. If there is no
   // item, unselect the current item.
@@ -281,10 +248,6 @@ void Smb4KNetworkBrowser::mousePressEvent(QMouseEvent *e)
     setCurrentItem(0);
     emit itemPressed(currentItem(), -1);
   }
-  else
-  {
-    // Do nothing
-  }
 
   QTreeWidget::mousePressEvent(e);
 }
@@ -304,10 +267,6 @@ void Smb4KNetworkBrowser::wheelEvent(QWheelEvent *e)
     m_tooltip_item->tooltip()->hide();
     m_tooltip_item = 0;
   }
-  else
-  {
-    // Do nothing
-  }
   
   QTreeWidget::wheelEvent(e);
 }
@@ -327,10 +286,6 @@ void Smb4KNetworkBrowser::slotItemEntered(QTreeWidgetItem *item, int /*column*/)
     m_tooltip_item->tooltip()->hide();
     m_tooltip_item = 0;
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -342,10 +297,6 @@ void Smb4KNetworkBrowser::slotViewportEntered()
     m_tooltip_item->tooltip()->hide();
     m_tooltip_item = 0;
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -357,10 +308,6 @@ void Smb4KNetworkBrowser::slotItemActivated(QTreeWidgetItem *item, int /*column*
     m_tooltip_item->tooltip()->hide();
     m_tooltip_item = 0;
   }
-  else
-  {
-    // Do nothing
-  }
 
   // Only do something if there are no keyboard modifiers pressed
   // and there is only one item selected.
@@ -390,14 +337,6 @@ void Smb4KNetworkBrowser::slotItemActivated(QTreeWidgetItem *item, int /*column*
         }
       }
     }
-    else
-    {
-      // Do nothing
-    }
-  }
-  else
-  {
-    // Do nothing
   }
 }
 
@@ -428,10 +367,6 @@ void Smb4KNetworkBrowser::slotItemSelectionChanged()
             {
               item->setSelected(false);
             }
-            else
-            {
-              // Do nothing
-            }
             break;
           }
           default:
@@ -440,15 +375,7 @@ void Smb4KNetworkBrowser::slotItemSelectionChanged()
           }
         }
       }
-      else
-      {
-        // Do nothing
-      }
     }
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
