@@ -2,7 +2,7 @@
     smb4knetworkbrowseritem  -  Smb4K's network browser list item.
                              -------------------
     begin                : Mo Jan 8 2007
-    copyright            : (C) 2007-2017 by Alexander Reinholdt
+    copyright            : (C) 2007-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -61,7 +61,7 @@ Smb4KNetworkBrowserItem::Smb4KNetworkBrowserItem(QTreeWidget *parent, const Netw
     {
       HostPtr host = m_item.staticCast<Smb4KHost>();
       setText(Network, host->hostName());
-      setText(IP, host->ip());
+      setText(IP, host->ipAddress());
       setText(Comment, host->comment());
       
       if (host->isMasterBrowser())
@@ -72,10 +72,6 @@ Smb4KNetworkBrowserItem::Smb4KNetworkBrowserItem(QTreeWidget *parent, const Netw
           setForeground(i, brush);
         }
       }
-      else
-      {
-        // Do nothing
-      }
 
       setIcon(Network, host->icon());
       break;
@@ -84,7 +80,7 @@ Smb4KNetworkBrowserItem::Smb4KNetworkBrowserItem(QTreeWidget *parent, const Netw
     {
       SharePtr share = m_item.staticCast<Smb4KShare>();
       setText(Network, share->shareName());
-      setText(Type, share->translatedTypeString());
+      setText(Type, share->shareTypeString());
       setText(Comment, share->comment());
 
       if (!share->isPrinter() && share->isMounted())
@@ -96,11 +92,7 @@ Smb4KNetworkBrowserItem::Smb4KNetworkBrowserItem(QTreeWidget *parent, const Netw
           setFont(i, f);
         }
       }
-      else
-      {
-        // Do nothing
-      }
-      
+
       setIcon(Network, share->icon());
       break;
     }
@@ -131,7 +123,7 @@ Smb4KNetworkBrowserItem::Smb4KNetworkBrowserItem(QTreeWidgetItem *parent, const
     {
       HostPtr host = m_item.staticCast<Smb4KHost>();
       setText(Network, host->hostName());
-      setText(IP, host->ip());
+      setText(IP, host->ipAddress());
       setText(Comment, host->comment());
       
       if (host->isMasterBrowser())
@@ -142,10 +134,6 @@ Smb4KNetworkBrowserItem::Smb4KNetworkBrowserItem(QTreeWidgetItem *parent, const
           setForeground(i, brush);
         }
       }
-      else
-      {
-        // Do nothing
-      }
 
       setIcon(Network, host->icon());
       break;
@@ -154,7 +142,7 @@ Smb4KNetworkBrowserItem::Smb4KNetworkBrowserItem(QTreeWidgetItem *parent, const
     {
       SharePtr share = m_item.staticCast<Smb4KShare>();
       setText(Network, share->shareName());
-      setText(Type, share->translatedTypeString());
+      setText(Type, share->shareTypeString());
       setText(Comment, share->comment());
 
       if (!share->isPrinter() && share->isMounted())
@@ -166,10 +154,6 @@ Smb4KNetworkBrowserItem::Smb4KNetworkBrowserItem(QTreeWidgetItem *parent, const
           setFont(i, f);
         }
       }
-      else
-      {
-        // Do nothing
-      }
       
       setIcon(Network, share->icon());
       break;
@@ -195,10 +179,6 @@ WorkgroupPtr Smb4KNetworkBrowserItem::workgroupItem()
   {
     return WorkgroupPtr();
   }
-  else
-  {
-    // Do nothing
-  }
   
   return m_item.staticCast<Smb4KWorkgroup>();
 }
@@ -210,10 +190,6 @@ HostPtr Smb4KNetworkBrowserItem::hostItem()
   {
     return HostPtr();
   }
-  else
-  {
-    // Do nothing
-  }
   
   return m_item.staticCast<Smb4KHost>();
 }
@@ -225,10 +201,6 @@ SharePtr Smb4KNetworkBrowserItem::shareItem()
   {
     return SharePtr();
   }
-  else
-  {
-    // Do nothing
-  }
   
   return m_item.staticCast<Smb4KShare>();
 }
@@ -267,7 +239,7 @@ void Smb4KNetworkBrowserItem::update()
       }
         
       // Set the IP address
-      setText(IP, host->ip());
+      setText(IP, host->ipAddress());
 
       // Set the comment 
       setText(Comment, host->comment());
