@@ -2,7 +2,7 @@
     This is the shares view of Smb4K.
                              -------------------
     begin                : Mo Dez 4 2006
-    copyright            : (C) 2006-2017 by Alexander Reinholdt
+    copyright            : (C) 2006-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -64,12 +64,11 @@ Smb4KSharesView::Smb4KSharesView(QWidget *parent)
   m_tooltipItem = 0;
   m_mouseInside = false;
 
-  // Connections:
-  connect(this, SIGNAL(itemEntered(QListWidgetItem*)),
-          this, SLOT(slotItemEntered(QListWidgetItem*)));
-
-  connect(this, SIGNAL(viewportEntered()),
-          this, SLOT(slotViewportEntered()));
+  // 
+  // Connections
+  // 
+  connect(this, SIGNAL(itemEntered(QListWidgetItem*)), this, SLOT(slotItemEntered(QListWidgetItem*)));
+  connect(this, SIGNAL(viewportEntered()), this, SLOT(slotViewportEntered()));
 }
 
 
@@ -147,10 +146,6 @@ bool Smb4KSharesView::event(QEvent *e)
             m_tooltipItem->tooltip()->hide();
             m_tooltipItem = 0;
           }
-          else
-          {
-            // Do nothing
-          }
         }
       }
       else
@@ -161,10 +156,6 @@ bool Smb4KSharesView::event(QEvent *e)
           m_tooltipItem->tooltip()->hide();
           m_tooltipItem = 0;
         }
-        else
-        {
-          // Do nothing
-        }
       }
 
       break;
@@ -187,10 +178,6 @@ void Smb4KSharesView::leaveEvent(QEvent *e)
     m_tooltipItem->tooltip()->hide();
     m_tooltipItem = 0;
   }
-  else
-  {
-    // Do nothing
-  }
   
   m_mouseInside = false;
   QListWidget::leaveEvent(e);
@@ -213,10 +200,6 @@ void Smb4KSharesView::mousePressEvent(QMouseEvent *e)
     m_tooltipItem->tooltip()->hide();
     m_tooltipItem = 0;
   }
-  else
-  {
-    // Do nothing
-  }
 
   // Get the item that is under the mouse. If there is no
   // item, unselect the current item.
@@ -228,10 +211,6 @@ void Smb4KSharesView::mousePressEvent(QMouseEvent *e)
     setCurrentItem(0);
     emit itemPressed(currentItem());
   }
-  else
-  {
-    // Do nothing
-  }
 
   QListWidget::mousePressEvent(e);
 }
@@ -251,10 +230,6 @@ void Smb4KSharesView::wheelEvent(QWheelEvent *e)
     m_tooltipItem->tooltip()->hide();
     m_tooltipItem = 0;
   }
-  else
-  {
-    // Do nothing
-  }
   
   QListWidget::wheelEvent(e);
 }
@@ -360,10 +335,6 @@ void Smb4KSharesView::startDrag(Qt::DropActions supported)
     m_tooltipItem->tooltip()->hide();
     m_tooltipItem = 0;
   }
-  else
-  {
-    // Do nothing
-  }
 
   QList<QListWidgetItem *> list = selectedItems();
 
@@ -395,10 +366,6 @@ void Smb4KSharesView::startDrag(Qt::DropActions supported)
 
     drag->exec(supported, Qt::IgnoreAction);
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -416,10 +383,6 @@ void Smb4KSharesView::slotItemEntered(QListWidgetItem *item)
     m_tooltipItem->tooltip()->hide();
     m_tooltipItem = 0;
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -432,9 +395,5 @@ void Smb4KSharesView::slotViewportEntered()
     m_tooltipItem->tooltip()->hide();
     m_tooltipItem = 0;
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
