@@ -2,7 +2,7 @@
     smb4ksystemtray  -  This is the system tray window class of Smb4K.
                              -------------------
     begin                : Mi Jun 13 2007
-    copyright            : (C) 2007-2017 by Alexander Reinholdt
+    copyright            : (C) 2007-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -36,7 +36,7 @@
 #include "core/smb4kshare.h"
 #include "core/smb4kglobal.h"
 #include "core/smb4kmounter.h"
-#include "core/smb4kscanner.h"
+#include "core/smb4kclient.h"
 
 // Qt includes
 #include <QMenu>
@@ -62,7 +62,7 @@ Smb4KSystemTray::Smb4KSystemTray(QWidget *parent)
   //
   // Set the icon for the system tray
   //
-  QString iconName = QStringLiteral("network-workgroup-symbolic");
+  QString iconName = QStringLiteral("network-workgroup");
   setIconByName(iconName);
   
   //
@@ -104,10 +104,10 @@ Smb4KSystemTray::Smb4KSystemTray(QWidget *parent)
   contextMenu()->addAction(action("config_action"));
   
   // 
-  // Connections:
+  // Connections
   // 
   connect(Smb4KMounter::self(), SIGNAL(mountedSharesListChanged()), SLOT(slotSetStatus()));
-  connect(Smb4KScanner::self(), SIGNAL(workgroups()), SLOT(slotSetStatus()));
+  connect(Smb4KClient::self(), SIGNAL(workgroups()), SLOT(slotSetStatus()));
 }
 
 
@@ -127,10 +127,6 @@ void Smb4KSystemTray::loadSettings()
   {
     bookmarkMenu->refreshMenu();
   }
-  else
-  {
-    // Do nothing
-  }
 
   // 
   // Adjust the shares menu
@@ -141,10 +137,6 @@ void Smb4KSystemTray::loadSettings()
   {
     sharesMenu->refreshMenu();
   }
-  else
-  {
-    // Do nothing
-  }
   
   //
   // Adjust the profiles menu
@@ -155,10 +147,6 @@ void Smb4KSystemTray::loadSettings()
   {
     profilesMenu->refreshMenu();
   }
-  else
-  {
-    // Do nothing
-  }
 }
 
 
@@ -168,7 +156,7 @@ void Smb4KSystemTray::loadSettings()
 
 void Smb4KSystemTray::slotMountDialog()
 {
-  Smb4KMounter::self()->openMountDialog(associatedWidget());
+  Smb4KMounter::self()->openMountDialog();
 }
 
 
@@ -182,10 +170,6 @@ void Smb4KSystemTray::slotConfigDialog()
     KConfigDialog::showDialog("ConfigDialog");
     return;
   }
-  else
-  {
-    // Do nothing
-  }
   
   //
   // If the dialog does not exist, load and show it:
@@ -215,10 +199,6 @@ void Smb4KSystemTray::slotConfigDialog()
       connect(dlg, SIGNAL(settingsChanged(QString)), this, SIGNAL(settingsChanged(QString)), Qt::UniqueConnection);
       dlg->show();
     }
-    else
-    {
-      // Do nothing
-    }
   }
   else
   {
